@@ -27,7 +27,6 @@
 #define __CALENDAR_CLIENT_H__
 
 #include <glib-object.h>
-#include <gdk/gdk.h>
 
 G_BEGIN_DECLS
 
@@ -73,6 +72,7 @@ typedef struct
 typedef struct
 {
   char   *uid;
+  char   *rid;
   char   *summary;
   char   *description;
   char   *color_string;
@@ -95,6 +95,7 @@ typedef struct
   GTime  due_time;
   guint  percent_complete;
   GTime  completed_time;
+  int    priority;
 } CalendarTask;
 
 typedef struct
@@ -139,10 +140,6 @@ void            calendar_client_set_task_completed       (CalendarClient     *cl
 							  char               *task_uid,
 							  gboolean            task_completed,
 							  guint               percent_complete);
-gboolean        calendar_client_launch_editor            (CalendarClient     *client,
-							  CalendarEventType   event_type,
-							  GdkScreen          *screen,
-							  GError            **error);
 
 void calendar_event_free (CalendarEvent *event);
 
